%createTimeLapseImage This script generates an image showing the bird at  
%   starting downstroke positions during its perch-to-perch flight
%
%   Dependencies: getFrames.m (required), getFlightInfo.m (optional) 

flight = 'Gaga5';
recordingDate = '11-7';
showTimes = []; % specify times to show if file is not in getFlightInfo.m 

addpath(['../' recordingDate '-15']);   % location of videos

% Get video frames
videoName = [flight '_13504.avi']; 
tskip = 3;
[ Frames, ~ ] = getFrames( videoName, .7, tskip );

% Get times to include in final image
if isempty(showTimes)
    fileName = [recordingDate '-' flight];
    [~, ~, startTimes, endTimes, ~] = getFlightInfo(fileName);
    showTimes = startTimes(1:1:end);
end

% Convert times to frames
fps = 3000/tskip; % frames per second of compressed video
include = round(showTimes*fps);

%% Create time-lapse image, subtracting out background (based on Frame 1)
thresh = 0.05;
gamma = 1.2;

showFrame = Frames{include(end)} - Frames{1};
mask = ~imfill(im2bw(showFrame, thresh), 'holes');
for f = length(include)-1:-1:2
    addMe = mask.*(Frames{include(f)} - Frames{1});                
    showFrame = showFrame + addMe;
    mask = ~imfill(im2bw(showFrame, thresh), 'holes');
end

warning off;
imshow(showFrame.^gamma);
