function [] = combineVideos( numVids, videoName, varargin )
%combineVideos Concatenate multiple videos into one video 
%   combineVideos(N, VIDEONAME, VIDEO1, VIDEO2, ...) creates VIDEONAME.avi
%   from concatenating the frames from N VIDEOS (N<=4). VIDEO1, VIDEO2, ...
%   are the frames to be combined. Videos should have same # of frames.
%
%   combineVideos(N, VIDEONAME, VIDEO1, VIDEO2, ..., START, END) combines
%   video frames between START and END

% Get frames for each input video
video = cell(1,numVids);
for i = 1:numVids
    video{i} = varargin{i};
end

if length(varargin) > numVids
    start = varargin{numVids+1} - 1;
    stop = varargin{numVids+2};
else
    start = 0;
    stop = length(video{1});
end
numFrames = stop - start;

% Scale first video if too large, cut to specified frames
[height, width] = size(video{1}{1});
maxheight = 400;
if height > maxheight
    for f = 1:numFrames
        video{1}{f} = imresize(video{1}{f+start}(:,:,1), maxheight/height);
    end
    width = maxheight/height*width;
    height = maxheight; 
else
    for f = 1:numFrames
        video{1}{f} = video{1}{f+start}(:,:,1);
    end
end

% Scale all other videos to have the same height as video 1
for v = 2:numVids
    scale = height/size(video{v}{1},1);
    % scale = width/size(video{v}{1},2);
    for f = 1:numFrames    
        video{v}{f} = imresize(video{v}{f+start}(:,:,1), scale);
    end
end

% Create new video
newVideo = VideoWriter(videoName);
newVideo.FrameRate = 30;    
open(newVideo);
for i = 1:numFrames
    h = figure(1); clf;
    if(numVids == 2)
        dh1 = max(size(video{2}{i},1)-size(video{1}{i},1),0) ;
        dh2 = max(size(video{1}{i},1)-size(video{2}{i},1),0) ;
        imshow([padarray(video{1}{i},dh1,'post') padarray(video{2}{i}, dh2,'post')]) ;
    elseif (numVids == 3)
        totalWidth = size(video{1}{i},2) + size(video{2}{i},2);
        dw = totalWidth - size(video{3}{i},2);
        imshow([video{1}{i} video{2}{i}; padarray(video{3}{i}, [0 dw], 'post')]);
    else
        totalHeight1 = size(video{1}{i},1) + size(video{2}{i},1);
        totalHeight2 = size(video{3}{i},1) + size(video{4}{i},1);
        dh1 = max(totalHeight2 - size(video{1}{i},1) - size(video{2}{i}, 1), 0);
        dh2 = max(totalHeight1 - size(video{3}{i},1) - size(video{4}{i}, 1), 0);
        imshow([padarray(video{1}{i},dh1,'post') video{2}{i}; padarray(video{3}{i},dh2,'post')]);
    end
    f = getframe(h);
    writeVideo(newVideo,f);
end
close(newVideo);
close;
end

