function [ Frames, nFrames ] = getFrames( fileName, res, tskip )
%getFrames Get frames of a video 
%   [FRAMES, NFRAMES] = getFrames(VIDEO, RESOLUTION, TSKIP) returns the
%   frames of VIDEO, lowering the resolution in space based on RESOLUTION
%   and in time based on TSKIP. Original frames are scaled by a factor of
%   RESOLUTION, and then only every TSKIP frames are returned in FRAMES.
%   NFRAMES is the number of frames in the new video.

% Read video
video = VideoReader(fileName);  
nFrames = video.NumberOfFrames;

% Lower resolution of frames for faster processing time
Frames = cell(1, floor(nFrames/tskip));
f = 1;
for i = 1:tskip:nFrames
    disp(['Processing frame ' sprintf('%d/%d', i,nFrames) ' of ' fileName '...']);
    Frames{f} = imresize(im2double(read(video, i)), res);
    f = f+1;
    clc;
end

nFrames = length(Frames);

end

