function [gamma, thresh, Rthresh, range1, range2a, range2b, range3a, range3b, range4, ...
    search, smoothAngle, initialDS, NP, flightType] = getParameters(flight, recordingDate)
%getParameters Returns parameters to process bottom view of flight video
%   [gamma, thresh, Rthresh, range1, range2a, range2b, range3a, range3b,
%   range4, search, smoothAngle, initialDS, NP, flightType] = 
%   getParameters(FLIGHT, DATE) returns the parameters needed to
%   process FLIGHT.avi recorded on DATE in ProcessBottomView.m

fileName = [recordingDate '-' flight];

if strcmp(fileName, '11-1-Aurora4')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .04;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 60;       % min distance to wingtip with preferred angle limits
    range2a = [20,110]; % preferred limits for second section
    range2b = [60,140]; % alternative limits for second section
    range3a = [20,170]; % preferred limits for third section
    range3b = [60,150]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [5, 270];  % frames to search for peaks
    smoothAngle = .07;  % smoothing level for stroke angle
    initialDS = 60;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Ascend';
elseif strcmp(fileName, '11-1-Aurora5')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .04;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 60;       % min distance to wingtip with preferred angle limits
    range2a = [20,110]; % preferred limits for second section
    range2b = [60,140]; % alternative limits for second section
    range3a = [30,170]; % preferred limits for third section
    range3b = [60,150]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [5, 240];  % frames to search for peaks
    smoothAngle = .07;  % smoothing level for stroke angle
    initialDS = 60;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Ascend';
elseif strcmp(fileName, '11-1-Aurora6')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .04;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 60;       % min distance to wingtip with preferred angle limits
    range2a = [20,110]; % preferred limits for second section
    range2b = [60,140]; % alternative limits for second section
    range3a = [30,170]; % preferred limits for third section
    range3b = [60,150]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [5, 250];  % frames to search for peaks
    smoothAngle = .07;  % smoothing level for stroke angle
    initialDS = 60;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Ascend';
    
elseif strcmp(fileName, '11-1-Aurora7')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .04;       % threshold for binarizing frames
    range1 = [30,120];   % stroke angle limits for first section of flight
    Rthresh = 30;       % min distance to wingtip with preferred angle limits
    range2a = [20,150]; % preferred limits for second section
    range2b = [30,120]; % alternative limits for second section
    range3a = [0,170]; % preferred limits for third section
    range3b = [5,150]; % alternative limits for third section
    range4 = [20, 170]; % angle limits for final section of flight
    search = [15, 250];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend';    
elseif strcmp(fileName, '11-1-Aurora8')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .04;       % threshold for binarizing frames
    range1 = [30,120];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [20,150]; % preferred limits for second section
    range2b = [30,120]; % alternative limits for second section
    range3a = [20,170]; % preferred limits for third section
    range3b = [45,150]; % alternative limits for third section
    range4 = [20, 170]; % angle limits for final section of flight
    search = [15, 200];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 60;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend';    
elseif strcmp(fileName, '11-1-Aurora9')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .04;       % threshold for binarizing frames
    range1 = [30,120];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [20,150]; % preferred limits for second section
    range2b = [30,120]; % alternative limits for second section
    range3a = [20,170]; % preferred limits for third section
    range3b = [45,150]; % alternative limits for third section
    range4 = [20, 170]; % angle limits for final section of flight
    search = [1, 200];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend';
    % CHANGE XMIN TO 319
elseif strcmp(fileName, '11-1-Aurora13')
    gamma = 1/6;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [30,120];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [20,100]; % preferred limits for second section
    range2b = [30,150]; % alternative limits for second section
    range3a = [20,170]; % preferred limits for third section
    range3b = [45,150]; % alternative limits for third section
    range4 = [20, 170]; % angle limits for final section of flight
    search = [15, 215];  % frames to search for peaks
    smoothAngle = .05;  % smoothing level for stroke angle
    initialDS = 50;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Level';    
elseif strcmp(fileName, '11-1-Aurora15')
    gamma = 1/2;        % for correcting contrast of frames
    thresh = .03;       % threshold for binarizing frames
    range1 = [30,120];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [20,100]; % preferred limits for second section
    range2b = [30,150]; % alternative limits for second section
    range3a = [20,170]; % preferred limits for third section
    range3b = [45,150]; % alternative limits for third section
    range4 = [20, 170]; % angle limits for final section of flight
    search = [1, 210];  % frames to search for peaks
    smoothAngle = .07;  % smoothing level for stroke angle
    initialDS = 50;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Level';    
elseif strcmp(fileName, '11-1-Aurora17')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [30,120];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [20,100]; % preferred limits for second section
    range2b = [30,150]; % alternative limits for second section
    range3a = [20,170]; % preferred limits for third section
    range3b = [45,150]; % alternative limits for third section
    range4 = [20, 170]; % angle limits for final section of flight
    search = [1, 250];  % frames to search for peaks
    smoothAngle = .05;  % smoothing level for stroke angle
    initialDS = 50;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Level';
    
    
elseif strcmp(fileName, '11-7-Gaga1')
    gamma = 1/4;        % for correcting contrast of frames
    thresh = .04;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [10,100]; % preferred limits for second section
    range2b = [30,100]; % alternative limits for second section
    range3a = [30,170]; % preferred limits for third section
    range3b = [10,170]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [80, 300];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 60;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Level';    
elseif strcmp(fileName, '11-7-Gaga2')
    gamma = 1/4;        % for correcting contrast of frames
    thresh = .04;       % threshold for binarizing frames
    range1 = [0,120];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [0, 120]; % preferred limits for second section
    range2b = [10,120]; % alternative limits for second section
    range3a = [20,180]; % preferred limits for third section
    range3b = [20,180]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [15, 250];  % frames to search for peaks
    smoothAngle = .05;  % smoothing level for stroke angle
    initialDS = 45;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Level';
elseif strcmp(fileName, '11-7-Gaga3')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [15,120];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [15,120]; % preferred limits for second section
    range2b = [15,120]; % alternative limits for second section
    range3a = [20,180]; % preferred limits for third section
    range3b = [20,180]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [15, 250];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 70;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Level';    
elseif strcmp(fileName, '11-7-Gaga4')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [15,90];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [20,120]; % preferred limits for second section
    range2b = [25,100]; % alternative limits for second section
    range3a = [20,180]; % preferred limits for third section
    range3b = [25,180]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [67, 270];  % frames to search for peaks
    smoothAngle = .07;  % smoothing level for stroke angle
    initialDS = 100;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Level';    
elseif strcmp(fileName, '11-7-Gaga5')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [0,100];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [0, 150]; % preferred limits for second section
    range2b = [20,150]; % alternative limits for second section
    range3a = [0, 180]; % preferred limits for third section
    range3b = [25,180]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [15, 250];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 20;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Level';
    
elseif strcmp(fileName, '11-7-Gaga7')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [10,100];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [0, 160]; % preferred limits for second section
    range2b = [20,150]; % alternative limits for second section
    range3a = [0, 180]; % preferred limits for third section
    range3b = [25,180]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [1, 240];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 20;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Ascend';    
elseif strcmp(fileName, '11-7-Gaga8')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [10,100];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [0, 160]; % preferred limits for second section
    range2b = [20,150]; % alternative limits for second section
    range3a = [0, 180]; % preferred limits for third section
    range3b = [25,180]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [1, 270];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 150;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Ascend';    
elseif strcmp(fileName, '11-7-Gaga9')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [10,100];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [0, 160]; % preferred limits for second section
    range2b = [20,150]; % alternative limits for second section
    range3a = [0, 180]; % preferred limits for third section
    range3b = [25,180]; % alternative limits for third section
    range4 = [40, 170]; % angle limits for final section of flight
    search = [1, 270];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Ascend';    
elseif strcmp(fileName, '11-7-Gaga10')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [10,100];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [20,140]; % preferred limits for second section
    range2b = [20,150]; % alternative limits for second section
    range3a = [20,180]; % preferred limits for third section
    range3b = [0, 180]; % alternative limits for third section
    range4 = [0, 180]; % angle limits for final section of flight
    search = [1, 250];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 50;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Ascend';
    % SET STARTFRAME = 1
elseif strcmp(fileName, '11-7-Gaga12')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [10,100];   % stroke angle limits for first section of flight
    Rthresh = 50;       % min distance to wingtip with preferred angle limits
    range2a = [-10,160]; % preferred limits for second section
    range2b = [0, 150]; % alternative limits for second section
    range3a = [0, 180]; % preferred limits for third section
    range3b = [0, 180]; % alternative limits for third section
    range4 = [0, 170]; % angle limits for final section of flight
    search = [1, 210];  % frames to search for peaks
    smoothAngle = .05;  % smoothing level for stroke angle
    initialDS = 50;     % threshold for finding initial downstroke time
    NP = 7;             % max number of peaks to identify
    flightType = 'Ascend';    
    
elseif strcmp(fileName, '11-7-Gaga14')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [10,70];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [0,120]; % preferred limits for second section
    range2b = [100,150]; % alternative limits for second section
    range3a = [0,170]; % preferred limits for third section
    range3b = [10, 120]; % alternative limits for third section
    range4 = [30, 180]; % angle limits for final section of flight
    search = [1, 250];  % frames to search for peaks
    smoothAngle = .07;  % smoothing level for stroke angle
    initialDS = 150;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend';
elseif strcmp(fileName, '11-7-Gaga16')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,100];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [0,150]; % preferred limits for second section
    range2b = [10,130]; % alternative limits for second section
    range3a = [20,180]; % preferred limits for third section
    range3b = [20, 180]; % alternative limits for third section
    range4 = [90, 180]; % angle limits for final section of flight
    search = [1, 230];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Descend';    
elseif strcmp(fileName, '11-7-Gaga17') 
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [30,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [10,150]; % preferred limits for second section
    range2b = [10,150]; % alternative limits for second section
    range3a = [10,160]; % preferred limits for third section
    range3b = [10,160]; % alternative limits for third section
    range4 = [30, 180]; % angle limits for final section of flight
    search = [50, 250];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend';  
elseif strcmp(fileName, '11-7-Gaga18')  
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [10,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [10,150]; % preferred limits for second section
    range2b = [10,150]; % alternative limits for second section
    range3a = [0,170]; % preferred limits for third section
    range3b = [0,160]; % alternative limits for third section
    range4 = [30, 180]; % angle limits for final section of flight
    search = [10, 250];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend';

    
elseif strcmp(fileName, '10-25-Gary3')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [10,100]; % preferred limits for second section
    range2b = [10,100]; % alternative limits for second section
    range3a = [0,170]; % preferred limits for third section
    range3b = [0,160]; % alternative limits for third section
    range4 = [10, 180]; % angle limits for final section of flight
    search = [50, 270];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Level';    
elseif strcmp(fileName, '10-25-Gary7')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [10,90]; % preferred limits for second section
    range2b = [10,100]; % alternative limits for second section
    range3a = [0,130]; % preferred limits for third section
    range3b = [20,130]; % alternative limits for third section
    range4 = [25, 180]; % angle limits for final section of flight
    search = [50, 290];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 50;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Level';    
elseif strcmp(fileName, '11-1-Gary9')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [0,120]; % preferred limits for second section
    range2b = [10,100]; % alternative limits for second section
    range3a = [0,150]; % preferred limits for third section
    range3b = [20,150]; % alternative limits for third section
    range4 = [15, 180]; % angle limits for final section of flight
    search = [30, 245];  % frames to search for peaks
    smoothAngle = .07;  % smoothing level for stroke angle
    initialDS = 50;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Level';    
elseif strcmp(fileName, '11-1-Gary12') 
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [0,90]; % preferred limits for second section
    range2b = [15,120]; % alternative limits for second section
    range3a = [0,180]; % preferred limits for third section
    range3b = [20,150]; % alternative limits for third section
    range4 = [25, 180]; % angle limits for final section of flight
    search = [15, 230];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Level';    
    
elseif strcmp(fileName, '10-25-Gary9')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [0,130]; % preferred limits for second section
    range2b = [5,130]; % alternative limits for second section
    range3a = [10,180]; % preferred limits for third section
    range3b = [10,180]; % alternative limits for third section
    range4 = [35, 180]; % angle limits for final section of flight
    search = [10, 300];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 130;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Ascend';    
elseif strcmp(fileName, '10-25-Gary10')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [0,130]; % preferred limits for second section
    range2b = [5,130]; % alternative limits for second section
    range3a = [10,180]; % preferred limits for third section
    range3b = [10,180]; % alternative limits for third section
    range4 = [35, 180]; % angle limits for final section of flight
    search = [5, 250];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 130;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Ascend';    
elseif strcmp(fileName, '10-25-Gary12')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 40;       % min distance to wingtip with preferred angle limits
    range2a = [0,130]; % preferred limits for second section
    range2b = [5, 90]; % alternative limits for second section
    range3a = [10,180]; % preferred limits for third section
    range3b = [10,180]; % alternative limits for third section
    range4 = [15, 180]; % angle limits for final section of flight
    search = [35, 260];  % frames to search for peaks
    smoothAngle = .05;  % smoothing level for stroke angle
    initialDS = 65;     % threshold for finding initial downstroke time
    NP = 10;             % max number of peaks to identify
    flightType = 'Ascend';    
    
elseif strcmp(fileName, '11-1-Gary2')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 30;       % min distance to wingtip with preferred angle limits
    range2a = [20,120]; % preferred limits for second section
    range2b = [10,100]; % alternative limits for second section
    range3a = [5, 170]; % preferred limits for third section
    range3b = [5, 150]; % alternative limits for third section
    range4 = [0, 170]; % angle limits for final section of flight
    search = [25, 230];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend';   
elseif strcmp(fileName, '11-1-Gary4')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 30;       % min distance to wingtip with preferred angle limits
    range2a = [20,150]; % preferred limits for second section
    range2b = [30,100]; % alternative limits for second section
    range3a = [0, 170]; % preferred limits for third section
    range3b = [5, 150]; % alternative limits for third section
    range4 = [10, 170]; % angle limits for final section of flight
    search = [25, 230];  % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend';
    
elseif strcmp(fileName, '11-1-Gary6')
    gamma = 1/3;        % for correcting contrast of frames
    thresh = .05;       % threshold for binarizing frames
    range1 = [20,90];   % stroke angle limits for first section of flight
    Rthresh = 30;       % min distance to wingtip with preferred angle limits
    range2a = [20,150]; % preferred limits for second section
    range2b = [30,100]; % alternative limits for second section
    range3a = [0, 170]; % preferred limits for third section
    range3b = [5, 150]; % alternative limits for third section
    range4 = [10, 170]; % angle limits for final section of flight
    search = [25, 250]; % frames to search for peaks
    smoothAngle = .04;  % smoothing level for stroke angle
    initialDS = 40;     % threshold for finding initial downstroke time
    NP = 9;             % max number of peaks to identify
    flightType = 'Descend'; 
end
    
end