function [ scaleStart, scaleEnd ] = getScaling( recordingDate, flightType )
%getScaling Get pixel to meter scaling factors for flight video
%   [SCALE_START, SCALE_END] = getScaling(DATE, TYPE) returns the pixel to
%   meter scaling factor for a flight recorded on DATE. SCALE_START
%   is the scaling factor near the takeoff perch, and SCALE_END is the
%   scaling factor near the landing perch. 
%   TYPE specifies the flight mode: 'Ascend', 'Level', or 'Descend'.

if strcmp(recordingDate, '11-1')
    x = [296.6, 407.3, 300.8];
    y = [418.4, 413.7, 531.6];
    d1 = sqrt((x(2)-x(1))^2 + (y(2)-y(1))^2);
    d2 = sqrt((x(3)-x(1))^2 + (y(3)-y(1))^2);
    d = .5*(d1+d2);
    scaleEnd = 0.10/d;% m/pix
    
    if strcmp(flightType, 'Level')
        scaleStart = scaleEnd;
        return;
    elseif strcmp(flightType, 'Descend')
        x = [331.1, 431.3];
        y = [398.6, 391.0];   
    elseif strcmp(flightType, 'Ascend')
        x = [221.2, 358.5];
        y = [425.3, 429.1];
    end
    d = sqrt((x(2)-x(1))^2 + (y(2)-y(1))^2);
    scaleStart = 0.10/d;

elseif strcmp(recordingDate, '11-7')
    x1 = [301.9, 410.4, 304.6];
    x2 = [301.6, 411.8, 304.8];
    y1 = [418.8, 420.4, 535.5];
    y2 = [417.5, 421.4, 535.6];
    x = .5*(x1+x2); y = .5*(y1+y2);
    d1 = sqrt((x(2)-x(1))^2 + (y(2)-y(1))^2);
    d2 = sqrt((x(3)-x(1))^2 + (y(3)-y(1))^2);
    d = .5*(d1+d2);
    scaleEnd = 0.10/d;% m/pix
    
    if strcmp(flightType, 'Level')
        scaleStart = scaleEnd;
        return;
    elseif strcmp(flightType, 'Descend')
        x = [334.2, 433.8];
        y = [402.2, 394.6];
        d = sqrt((x(2)-x(1))^2 + (y(2)-y(1))^2);
    elseif strcmp(flightType, 'Ascend')
        x = [220.6, 356.7, 224.2];
        y = [431.4, 435.5, 572.4];
        d1 = sqrt((x(2)-x(1))^2 + (y(2)-y(1))^2);
        d2 = sqrt((x(3)-x(1))^2 + (y(3)-y(1))^2);
        d = .5*(d1+d2);        
    end    
    scaleStart = 0.10/d;
    
elseif strcmp(recordingDate, '10-25')    
    x = [376.0, 481.3, 379.8];
    y = [395.4, 392.5, 508.9];
    d1 = sqrt((x(2)-x(1))^2 + (y(2)-y(1))^2);
    d2 = sqrt((x(3)-x(1))^2 + (y(3)-y(1))^2);
    d = .5*(d1+d2);
    scaleEnd = 0.10/d;% m/pix
    
    if strcmp(flightType, 'Level')
        scaleStart = scaleEnd;
    elseif strcmp(flightType, 'Ascend')
        x = [327.4, 461.4, 332.6];
        y = [407.6, 409.3, 547.6];
        d1 = sqrt((x(2)-x(1))^2 + (y(2)-y(1))^2);
        d2 = sqrt((x(3)-x(1))^2 + (y(3)-y(1))^2);
        d = .5*(d1+d2);
        scaleStart = 0.10/d;        
    end
   
end

end
