function [varargout] = makeVideo( videoName, Frames, start, stop, varargin )
%makeVideo Create and display video
%   makeVideo(VIDEONAME, FRAMES, START, STOP) creates VIDEONAME.avi from 
%   FRAMES. START and STOP are the indices of the first and last frames to 
%   include in the video. 
%
%   F = makeVideo(VIDEONAME, FRAMES, START, STOP, POINTS) also plots POINTS
%   on top of each frame. Frames of the final movie are returned in F. 

newVideo = VideoWriter(videoName);
newVideo.FrameRate = 20;

start = start - 1;
numFrames = stop - start;
newFrames = cell(1,numFrames);

scale = 300/size(Frames{1},1);
[height, width] = size(imresize(Frames{1}, scale));

open(newVideo);
for i = 1:numFrames
    h = figure(1); clf; 
    Frames{i} = imresize(Frames{i+start},scale);
    
    imshow(Frames{i}); 
    if ~isempty(varargin)
        hold on;
        point = varargin{1};
        x = point(i,1)*scale;
        y = point(i,2)*scale;
        plot(x, y, 'ko', 'MarkerSize', 10*scale, 'LineWidth', 2*scale);
        plot(x, y, 'yo', 'MarkerSize', 5*scale, 'LineWidth', 1*scale);
        plot([width/2 .8*width], [height/2+3 height/2+3], 'y', 'LineWidth', 2);
        plot([width/2 x], [height/2+3 y], 'y', 'LineWidth', 3);
    end
    F = getframe(h);
    newFrames{i} = F.cdata;
    writeVideo(newVideo,F);
end
close(newVideo);
varargout{1} = newFrames;
close;

end

