function [] = showVideoWithPlot( video, t, y, strokeStart, strokeEnd, varargin )
%showVideoWithPlot displays plot below movie
%   showVideoWithPlot(VIDEO, T, Y) displays VIDEO above a plot of Y vs. T.
%   Y and T must have the same number of points as frames in VIDEO
%
%   showVideoWithPlot(VIDEO, T, Y, XLABEL, YLABEL, TITLE) labels the axes
%   and titles the plot of Y vs. T
%
%   showVideoWithPlot(VIDEO, T, Y, XLABEL, YLABEL, TITLE, VIDEONAME) 
%   saves the new video as VIDEONAME.avi

[ Frames, nFrames ] = getFrames( video, 1, 1 ); % get frames from video

if length(varargin) >= 3
    hold on;
    Xlabel = varargin{1};
    Ylabel = varargin{2};
    Title = varargin{3};
end

if length(varargin) == 4    
    videoName = varargin{4};
    newVideo = VideoWriter(videoName);
    newVideo.FrameRate = 10;  
    open(newVideo);
end
        
for i = 1:nFrames     
    h = figure(1); clf;
    subplot('position', [0 0.35 1 .6]);
    imshow(Frames{i}); 

    subplot('position', [.1 .1 .8 .25]);
    hold on;
    for k = 1:min(length(strokeEnd), length(strokeStart))       
        area([strokeStart(k) strokeEnd(k)], 180*[1 1], 0,...
            'FaceColor', [.8, .8, .8], 'EdgeColor', 'none');
    end
    area([t(i) max(t)], 180*[1 1],  0, 'FaceColor', [1, 1, 1], 'EdgeColor', 'none');
    plot(t(1:i),y(1:i), 'k', 'LineWidth', 2); axis([min(t) max(t) 0 1.2*max(y)]);
    ylim([0 180]);
    if length(varargin) >=3, 
        xlabel(Xlabel); ylabel(Ylabel); title(Title); 
    end    
    set(gca, 'FontSize', 12);
    f = getframe(h);
    if length(varargin) == 4     
        writeVideo(newVideo,f);
    end
end

if length(varargin) == 3
    close(newVideo);
end

end
